webuse nhanes2l, clear


* single estimation result
regress bpsystol age weight i.region

etable


etable, cstat(_r_b) cstat(_r_se) ///
	cstat(_r_ci) mstat(N) mstat(r2) ///
	showstars showstarsnote ///
	export("test.docx", replace)

	
* mutliple estimation result
quietly logistic diabetes age i.sex i.race bmi
estimates store e1

quietly logistic diabetes age
estimates store e2

quietly logistic diabetes i.sex
estimates store e3

quietly logistic diabetes i.race
estimates store e4

quietly logistic diabetes bmi
estimates store e5

etable, column(index) estimates(e1 e2 e3 e4 e5) showstars showstarsnote ///
	title(Logistic regression results comparison) note(DV=diabetes)

** using append

quietly logistic diabetes age i.sex i.race bmi
etable

quietly logistic diabetes age
etable, append

quietly logistic diabetes i.sex
etable, append

quietly logistic diabetes i.race
etable, append

quietly logistic diabetes bmi
etable, append column(index) estimates(e1 e2 e3 e4 e5) showstars showstarsnote ///
	title(Logistic regression results comparison) note(DV=diabetes)

* margins result 
quietly logistic diabetes age i.sex i.race bmi
margins race
etable, margins column(command)

quietly logistic diabetes age i.sex i.race bmi
margins race
etable, margins column(command)
margins sex
etable, margins column(command) append
quietly logistic diabetes age i.sex i.race bmi
etable
margins race
etable, margins append
 
margins sex
etable, margins column(command) append
 
******************************************
* replay feature

quietly logistic diabetes age i.sex i.race bmi
etable, mstat(N, nformat(%9.0g)) mstat(aic, nformat(%9.3f)) mstat(bic, nformat(%9.3f)) mstat(r2_p, nformat(%9.3f))


etable, replay
etable, replay column(command)
etable, replay note("DV=diabetes")
etable, replay title("logistic model results")

* equals

etable, mstat(N, nformat(%9.0g)) mstat(aic, nformat(%9.3f)) /// 
	mstat(bic, nformat(%9.3f)) mstat(r2_p, nformat(%9.3f)) ///
	column(command) note("DV=diabetes") title("logistic model results")


********************************************************************************
* customization using -etable- options

quietly logistic diabetes age i.sex i.race bmi
etable, mstat(N, nformat(%9.0g)) ///
	mstat(aic, nformat(%9.3f)) ///
	mstat(bic, nformat(%9.3f)) ///
	mstat(r2_p, nformat(%9.3f))

etable, mstat(N, nformat(%9.0g)) /// 
	keep(age sex race bmi)
etable, mstat(_hide)
etable, cstat(_r_b) cstat(_r_ci)
etable, cstat(_r_b, font(,bold)) /// 
	cstat(_r_ci, cidelimiter(",") sformat("(%s)"))
etable, showstars showstarsnote 
etable, showstars showstarsnote ///
	stars(0.05 "*" 0.01 "**" 0.001 "***")


etable, title("Logistic Regression Model for Diabetes") /// 
	titlestyles(font(Lucida Conaole, size(14) bold)) ///
	note("Data Source: NHANES, 1981") ///
	notestyles(font(Lucida Conaole, size(10) italic))
etable, mstat(chi2) mstat(chi2p=e(p), nformat(%5.4f) label("p-value for model test"))

* equation recode
regress bpsystol age weight i.sex
estimates store a1
regress bpdiast age weight i.sex
estimates store a2

etable, estimates(a1 a2)

etable, replay eqrecode(bpdiast=bpsystol)

* customization using collect

etable, column(index) estimates(e1 e2 e3 e4 e5) showstars showstarsnote ///
	title(Logistic regression results comparison) note(DV=diabetes)

collect layout (coleq#colname#result[_r_b _r_se] result[N]) (cmdset#stars) (), name(ETable)
collect style row split, binder(" = ") dups(first)
collect style header result, level(value)
collect layout

collect label dim cmdset "Model index", modify
collect style header cmdset, title(label)
collect layout

etable, showstars showstarsnote export("test.docx", replace)
collect export "test.docx", replace


